@@ -1,6 +1,4 @@
-/* 21sep18abu
- * (c) Software Lab. Alexander Burger
- */
+/* 13jun19 Software Lab. Alexander Burger */
 
 var FormReq = new XMLHttpRequest();
 FormReq.upload.addEventListener("progress", dropProgress, false);
@@ -8,7 +6,7 @@ FormReq.upload.addEventListener("load", dropLoad, false);
 
 var Btn = [];
 var Queue = [];
-var SesId, Key, InBtn, Auto, Chg, Drop, Hint, Hints, Item, Beg, End;
+var Busy, SesId, Key, InBtn, Auto, Chg, Drop, Hint, Hints, Item, Beg, End;
 
 function inBtn(btn,flg) {InBtn = flg;}
 
@@ -117,16 +115,15 @@ function post(form, auto, exe, file) {
 
    if (!FormReq || !hasElement(form,"*Get") || (i = form.action.indexOf("~")) <= 0)
       return true;
-   if (FormReq.readyState > 0 && FormReq.readyState < 4) {
+   if (Busy) {
       Queue.push([form, auto, exe, file]);
       return false;
    }
+   Busy = true;
    form.style.cursor = "wait";
    try {FormReq.open("POST", SesId + "!jsForm?" + form.action.substr(i+1));}
    catch (e) {return true;}
    FormReq.onload = function() {
-      var i, j;
-
       if (FormReq.responseText == "T") {
          Queue.length = 0;
          form.submit();
@@ -153,6 +150,8 @@ function post(form, auto, exe, file) {
             }
          }
          if (!auto || !Chg) {
+            var i, j;
+
             for (i = 1; i < txt.length;) {
                var fld = txt[i++];
                var val = decodeURIComponent(txt[i++]);
@@ -302,6 +301,7 @@ function post(form, auto, exe, file) {
                   }
                }
             }
+            Busy = false;
             Chg = false;
          }
       }
@@ -597,8 +597,12 @@ function lispVal(x) {
 }
 
 function ping(min) {
-   if (SesId) {
-      lisp(null, "ping", min);
-      setTimeout(function() {ping(min)}, 20000);
-   }
+   Busy = false;
+   if (SesId)
+      setTimeout(function() {ping1(min)}, 20000);
+}
+
+function ping1(min) {
+   lisp(null, "ping", min);
+   setTimeout(function() {ping1(min)}, 20000);
 }
