@@ -1,4 +1,4 @@
-/* 09jan17abu
+/* 21dec18abu
  * (c) Software Lab. Alexander Burger
  */
 
@@ -36,7 +36,7 @@ any Intern[IHASH], Transient[IHASH], Extern[EHASH];
 any ApplyArgs, ApplyBody, DbVal, DbTail;
 any Nil, DB, Meth, Quote, T;
 any Solo, PPid, Pid, At, At2, At3, This, Prompt, Dbg, Zap, Ext, Scl, Class;
-any Run, Hup, Sig1, Sig2, Up, Err, Msg, Uni, Led, Tsm, Adr, Fork, Bye;
+any Run, Hup, Sig1, Sig2, Up, Err, Msg, Uni, Led, Adr, Fork, Bye;
 bool Break;
 sig_atomic_t Signal[NSIG];
 
@@ -1118,7 +1118,7 @@ any doCd(any x) {
    }
 }
 
-// (ctty 'sym|pid) -> flg
+// (ctty 'sym|NIL|pid) -> flg
 any doCtty(any ex) {
    any x;
 
@@ -1127,7 +1127,7 @@ any doCtty(any ex) {
    else {
       if (!isSym(x))
          argError(ex,x);
-      {
+      if (!isNil(x)) {
          char tty[bufSize(x)];
 
          bufString(x, tty);
@@ -1135,9 +1135,10 @@ any doCtty(any ex) {
             return Nil;
          InFiles[STDIN_FILENO]->ix = InFiles[STDIN_FILENO]->cnt = InFiles[STDIN_FILENO]->next = 0;
          Tio = tcgetattr(STDIN_FILENO, &OrgTermio) == 0;
-         OutFiles[STDOUT_FILENO]->tty = YES;
          OutFiles[STDOUT_FILENO]->ix = 0;
       }
+      OutFiles[STDOUT_FILENO]->tty = YES;
+      OutFiles[STDERR_FILENO]->tty = YES;
    }
    return T;
 }
