@@ -1,4 +1,4 @@
-/* 02sep17abu
+/* 21dec18abu
  * (c) Software Lab. Alexander Burger
  */
 
@@ -44,7 +44,7 @@
 #define CELLS (1024*1024/sizeof(cell)) // Heap allocation unit 1MB
 #define IHASH 4999                     // Internal hash table size (should be prime)
 #define EHASH 49999                    // External hash table size (should be prime)
-#define TOP 0x10000                    // Character Top
+#define TOP 0x110000                   // Character Top
 
 typedef unsigned long word;
 typedef unsigned char byte;
@@ -259,7 +259,7 @@ extern any Intern[IHASH], Transient[IHASH], Extern[EHASH];
 extern any ApplyArgs, ApplyBody, DbVal, DbTail;
 extern any Nil, DB, Meth, Quote, T;
 extern any Solo, PPid, Pid, At, At2, At3, This, Prompt, Dbg, Zap, Ext, Scl, Class;
-extern any Run, Hup, Sig1, Sig2, Up, Err, Msg, Uni, Led, Tsm, Adr, Fork, Bye;
+extern any Run, Hup, Sig1, Sig2, Up, Err, Msg, Uni, Led, Adr, Fork, Bye;
 extern bool Break;
 extern sig_atomic_t Signal[NSIG];
 
